==> ejc-zdsstore-api-3.0.0-20231224.063958-32-sources.jar: com/ejianc/business/zdsstore/vo/PickReturnExportVO.java <==
package com.ejianc.business.zdsstore.vo;

import java.math.BigDecimal;

/**
 * 材料退库表
 * 
 * @author generator
 * 
 */
public class PickReturnExportVO{
    private static final long serialVersionUID = 1L;
    

    private String billCode; // 退库单号
    private String instoreDate; // 退库日期
    private String projectName; // 所属项目名称
    private String subOrgName; // 分包单位名称
    private String managerName; // 负责人姓名
    private String materialNames; // 材料分类名称
    private BigDecimal totalTaxMny; // 退库金额含税
    private String employeeName; // 经办人
    private String billState; // 单据状态
    private String createTime;//创建时间

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getInstoreDate() {
        return instoreDate;
    }

    public void setInstoreDate(String instoreDate) {
        this.instoreDate = instoreDate;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getSubOrgName() {
        return subOrgName;
    }

    public void setSubOrgName(String subOrgName) {
        this.subOrgName = subOrgName;
    }

    public String getManagerName() {
        return managerName;
    }

    public void setManagerName(String managerName) {
        this.managerName = managerName;
    }

    public String getMaterialNames() {
        return materialNames;
    }

    public void setMaterialNames(String materialNames) {
        this.materialNames = materialNames;
    }

    public BigDecimal getTotalTaxMny() {
        return totalTaxMny;
    }

    public void setTotalTaxMny(BigDecimal totalTaxMny) {
        this.totalTaxMny = totalTaxMny;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getBillState() {
        return billState;
    }

    public void setBillState(String billState) {
        this.billState = billState;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }
}

==> ejc-zdsstore-api-3.0.0-20240109.124832-94-sources.jar: com/ejianc/business/zdsstore/vo/PickReturnExportVO.java <==
package com.ejianc.business.zdsstore.vo;

import java.math.BigDecimal;

/**
 * 材料退库表
 * 
 * @author generator
 * 
 */
public class PickReturnExportVO{
    private static final long serialVersionUID = 1L;
    

    private String billCode; // 退库单号
    private String instoreDate; // 退库日期
    private String projectName; // 所属项目名称
    private String subOrgName; // 分包单位名称
    private String managerName; // 负责人姓名
    private String materialNames; // 材料分类名称
    private BigDecimal totalTaxMny; // 退库金额含税
    private String employeeName; // 经办人
    private String billState; // 单据状态
    private String createTime;//创建时间
    private String pickReturnName; // 退料人

    public String getPickReturnName() {
        return pickReturnName;
    }

    public void setPickReturnName(String pickReturnName) {
        this.pickReturnName = pickReturnName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getInstoreDate() {
        return instoreDate;
    }

    public void setInstoreDate(String instoreDate) {
        this.instoreDate = instoreDate;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getSubOrgName() {
        return subOrgName;
    }

    public void setSubOrgName(String subOrgName) {
        this.subOrgName = subOrgName;
    }

    public String getManagerName() {
        return managerName;
    }

    public void setManagerName(String managerName) {
        this.managerName = managerName;
    }

    public String getMaterialNames() {
        return materialNames;
    }

    public void setMaterialNames(String materialNames) {
        this.materialNames = materialNames;
    }

    public BigDecimal getTotalTaxMny() {
        return totalTaxMny;
    }

    public void setTotalTaxMny(BigDecimal totalTaxMny) {
        this.totalTaxMny = totalTaxMny;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getBillState() {
        return billState;
    }

    public void setBillState(String billState) {
        this.billState = billState;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }
}
